package com.example.pdftronsampleactivity

import android.net.Uri
import android.os.Bundle
import android.view.Menu
import android.view.MenuInflater
import android.view.MenuItem
import androidx.appcompat.app.AppCompatActivity
import com.pdftron.pdf.PDFDoc
import com.pdftron.pdf.PDFViewCtrl
import com.pdftron.pdf.config.ViewerBuilder2
import com.pdftron.pdf.config.ViewerConfig
import com.pdftron.pdf.controls.PdfViewCtrlTabHostFragment2
import com.pdftron.pdf.model.FileInfo
import com.pdftron.pdf.utils.Utils
import com.pdftron.pdf.widget.toolbar.builder.AnnotationToolbarBuilder
import com.pdftron.pdf.widget.toolbar.builder.ToolbarButtonType
import com.pdftron.pdf.widget.toolbar.component.DefaultToolbars

class MainActivity : AppCompatActivity(), PdfViewCtrlTabHostFragment2.TabHostListener {

    private lateinit var mHostFragment: PdfViewCtrlTabHostFragment2
    private var mPdfViewCtrl: PDFViewCtrl? = null
    private var mPdfDoc: PDFDoc? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val file = Utils.copyResourceToLocal(this, R.raw.sample, "sample", ".pdf")

        val config = ViewerConfig.Builder()
            .addToolbarBuilder(getToolbar())
            .toolbarTitle(getString(R.string.app_name))
            .showToolbarSwitcher(false)
            .hidePresetBar(true)
            .multiTabEnabled(false)
            .showThumbnailView(false)
            .showSearchView(false)
            .showReflowOption(false)
            .showBookmarksView(false)
            .showShareOption(false)
            .showDocumentSettingsOption(false)
            .showEditPagesOption(false)
            .showSaveCopyOption(false)
            .showPrintOption(false)
            .showCloseTabOption(false)
            .showTopToolbar(false)
            .build()

        mHostFragment = ViewerBuilder2
            .withUri(Uri.fromFile(file))
            .usingConfig(config)
            .usingTheme(R.style.Theme_PdftronSampleActivity)
            .build(this)

        supportFragmentManager.beginTransaction()
            .replace(R.id.fragment_container, mHostFragment)
            .commit()

        mHostFragment.addHostListener(this)
    }

    private fun getToolbar(): AnnotationToolbarBuilder {
        return AnnotationToolbarBuilder.withTag("Toolbar")
            .addToolButton(
                ToolbarButtonType.INK,
                DefaultToolbars.ButtonId.INK.value()
            )
            .addToolButton(ToolbarButtonType.ARROW, DefaultToolbars.ButtonId.ARROW.value())
            .addToolButton(
                ToolbarButtonType.LINE,
                DefaultToolbars.ButtonId.LINE.value()
            )
            .addToolButton(ToolbarButtonType.IMAGE, DefaultToolbars.ButtonId.IMAGE.value())
    }

    override fun onTabHostShown() {
    }

    override fun onTabHostHidden() {
    }

    override fun onLastTabClosed() {
    }

    override fun onTabChanged(tag: String?) {
    }

    override fun onOpenDocError(): Boolean {
        return false
    }

    override fun onNavButtonPressed() {
    }

    override fun onShowFileInFolder(fileName: String?, filepath: String?, itemSource: Int) {
    }

    override fun canShowFileInFolder(): Boolean {
        return false
    }

    override fun canShowFileCloseSnackbar(): Boolean {
        return false
    }

    override fun onToolbarCreateOptionsMenu(menu: Menu?, inflater: MenuInflater?): Boolean {
        return false
    }

    override fun onToolbarPrepareOptionsMenu(menu: Menu?): Boolean {
        return false
    }

    override fun onToolbarOptionsItemSelected(item: MenuItem?): Boolean {
        return false
    }

    override fun onStartSearchMode() {
    }

    override fun onExitSearchMode() {
    }

    override fun canRecreateActivity(): Boolean {
        return false
    }

    override fun onTabPaused(fileInfo: FileInfo?, isDocModifiedAfterOpening: Boolean) {
    }

    override fun onJumpToSdCardFolder() {
    }

    override fun onTabDocumentLoaded(tag: String?) {
        // Do your custom logic here
        mPdfViewCtrl = mHostFragment.currentPdfViewCtrlFragment?.pdfViewCtrl
        mPdfDoc = mPdfViewCtrl?.doc
    }

}